import os

import matplotlib
matplotlib.use('agg')
from matplotlib import pyplot

import numpy as np
from scipy.optimize import curve_fit
from scipy.integrate import quad

import common
from common import draw_classic_axes

def plot_curie():    
    B = np.linspace(-2, 2, 1000)
    fig, ax = pyplot.subplots()

    sqrt_plus = lambda x: np.sqrt(x * (x >= 0))
    ax.plot(B, np.tanh(B * 3), label="low $T$")
    ax.plot(B, np.tanh(B), label="high $T$")

    ax.legend()
    ax.set_ylabel("$M$")
    ax.set_xlabel("$B$")
    draw_classic_axes(ax, xlabeloffset=.2)
    fig.savefig('curie.svg')


def plot_free_electron_DOS():    
    E = np.linspace(0, 2, 500)
    fig, ax = pyplot.subplots()

    ax.plot(E, np.sqrt(E))

    ax.set_ylabel(r"$g(\varepsilon)$")
    ax.set_xlabel(r"$\varepsilon$")
    draw_classic_axes(ax, xlabeloffset=.2)
    fig.savefig('sqrt.svg')


def plot_finite_T_FEM():
    E = np.linspace(0, 2, 500)
    fig, ax = pyplot.subplots()
    ax.plot(E, np.sqrt(E), linestyle='dashed')
    ax.text(1.7, 1.4, r'$g(\varepsilon)\propto \sqrt{\varepsilon}$', ha='center')
    ax.fill_between(E, np.sqrt(E) * (E < 1), alpha=.3)
    
    n = np.sqrt(E) / (1 + np.exp(20*(E-1)))
    ax.plot(E, n)
    ax.fill_between(E, n, alpha=.5)
    w = .17
    ax.annotate(s='', xy=(1, 1), xytext=(1-w, 1),
                arrowprops=dict(arrowstyle='<->', shrinkA=0, shrinkB=0))
    ax.text(1-w/2, 1.15, r'$\sim k_BT$', ha='center')
    ax.plot([1-w, 1+w], [1, 0], c='k', linestyle='dashed')
    ax.annotate(s='', xy=(1, 0), xytext=(1, 1),
                arrowprops=dict(arrowstyle='<->', shrinkA=0, shrinkB=0))
    ax.text(1.2, .9, r'$g(\varepsilon_F)$', ha='center')
    ax.set_xticks([1])
    ax.set_xticklabels([r'$\varepsilon_F$'])

    ax.set_ylabel(r"$g(\varepsilon)$")
    ax.set_xlabel(r"$\varepsilon$")
    draw_classic_axes(ax, xlabeloffset=.2)
    
    fig.savefig('FD_DOS.svg')

def main():
    os.chdir('docs/figures')
    plot_curie()
    plot_free_electron_DOS()
    plot_finite_T_FEM()

if __name__ == "__main__":
    main()
